package com.sun.tools.jdeps.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "21.0.6+7-LTS" },
            { "jdk", "21.0.6" },
            { "release", "21.0.6" },
        };
    }
}
